==> aliyun-python-sdk-companyreg-1.2.1.tar.gz: aliyun-python-sdk-companyreg-1.2.1/aliyunsdkcompanyreg/request/v20190508/AcceptPartnerNotificationRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class AcceptPartnerNotificationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2019-05-08', 'AcceptPartnerNotification')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_CertificateEndTime(self):
		return self.get_query_params().get('CertificateEndTime')

	def set_CertificateEndTime(self,CertificateEndTime):
		self.add_query_param('CertificateEndTime',CertificateEndTime)

	def get_ApplicationStatus(self):
		return self.get_query_params().get('ApplicationStatus')

	def set_ApplicationStatus(self,ApplicationStatus):
		self.add_query_param('ApplicationStatus',ApplicationStatus)

	def get_CertificateNumber(self):
		return self.get_query_params().get('CertificateNumber')

	def set_CertificateNumber(self,CertificateNumber):
		self.add_query_param('CertificateNumber',CertificateNumber)

	def get_OfficialFileURL(self):
		return self.get_query_params().get('OfficialFileURL')

	def set_OfficialFileURL(self,OfficialFileURL):
		self.add_query_param('OfficialFileURL',OfficialFileURL)

	def get_CertificateStartTime(self):
		return self.get_query_params().get('CertificateStartTime')

	def set_CertificateStartTime(self,CertificateStartTime):
		self.add_query_param('CertificateStartTime',CertificateStartTime)

	def get_BizId(self):
		return self.get_query_params().get('BizId')

	def set_BizId(self,BizId):
		self.add_query_param('BizId',BizId)

==> aliyun-python-sdk-companyreg-2.2.2.tar.gz: aliyun-python-sdk-companyreg-2.2.2/aliyunsdkcompanyreg/request/v20190508/AcceptPartnerNotificationRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkcompanyreg.endpoint import endpoint_data

class AcceptPartnerNotificationRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'companyreg', '2019-05-08', 'AcceptPartnerNotification')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_CertificateEndTime(self): # String
		return self.get_query_params().get('CertificateEndTime')

	def set_CertificateEndTime(self, CertificateEndTime):  # String
		self.add_query_param('CertificateEndTime', CertificateEndTime)
	def get_ApplicationStatus(self): # Integer
		return self.get_query_params().get('ApplicationStatus')

	def set_ApplicationStatus(self, ApplicationStatus):  # Integer
		self.add_query_param('ApplicationStatus', ApplicationStatus)
	def get_CertificateNumber(self): # String
		return self.get_query_params().get('CertificateNumber')

	def set_CertificateNumber(self, CertificateNumber):  # String
		self.add_query_param('CertificateNumber', CertificateNumber)
	def get_OfficialFileURL(self): # String
		return self.get_query_params().get('OfficialFileURL')

	def set_OfficialFileURL(self, OfficialFileURL):  # String
		self.add_query_param('OfficialFileURL', OfficialFileURL)
	def get_CertificateStartTime(self): # String
		return self.get_query_params().get('CertificateStartTime')

	def set_CertificateStartTime(self, CertificateStartTime):  # String
		self.add_query_param('CertificateStartTime', CertificateStartTime)
	def get_BizId(self): # String
		return self.get_query_params().get('BizId')

	def set_BizId(self, BizId):  # String
		self.add_query_param('BizId', BizId)
